package com.gxzc.zen.api.sys.service.impl

import com.baomidou.mybatisplus.mapper.EntityWrapper
import com.baomidou.mybatisplus.service.impl.ServiceImpl
import com.gxzc.zen.api.sys.mapper.SysResourceMapper
import com.gxzc.zen.api.sys.model.SysResource
import com.gxzc.zen.api.sys.service.ISysPermissionService
import com.gxzc.zen.api.sys.service.ISysResourceRoleService
import com.gxzc.zen.api.sys.service.ISysResourceService
import com.gxzc.zen.common.exception.ZenException
import com.gxzc.zen.common.exception.ZenExceptionEnum
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Service
import org.springframework.transaction.annotation.Transactional

/**
 * <p>
 * 资源表 服务实现类
 * </p>
 *
 * @author NorthLan
 * @since 2018-04-28
 */
@Service
class SysResourceServiceImpl : ServiceImpl<SysResourceMapper, SysResource>(), ISysResourceService {
    @Autowired
    private lateinit var permissionService: ISysPermissionService

    @Autowired
    private lateinit var resourceRoleService: ISysResourceRoleService

    override fun getResourcesByRoleIds(roleIds: List<Long>): MutableList<SysResource> {
        return baseMapper.selectByRoleIds(roleIds)
    }

    override fun getResourcesByRoleId(roleId: Long): MutableList<SysResource> {
        return baseMapper.selectByRoleId(roleId)
    }

    override fun getResourcesByMenuId(menuId: Long): MutableList<SysResource> {
        val condition = SysResource().apply {
            this.menuId = menuId
        }
        return baseMapper.selectList(EntityWrapper(condition))
    }

    override fun insertResource(menuId: Long, sysResource: SysResource): SysResource {
        sysResource.menuId = menuId
        if (baseMapper.insert(sysResource) <= 0) {
            throw ZenException(ZenExceptionEnum.BIZ_INSERT_ERROR)
        }

        permissionService.updateAllSysPermission()

        return sysResource
    }

    override fun updateResource(sysResource: SysResource): SysResource {
        if (baseMapper.updateById(sysResource) <= 0) {
            throw ZenException(ZenExceptionEnum.BIZ_INSERT_ERROR)
        }

        /////
        permissionService.updateAllSysPermission()
        permissionService.updateAllSessionPermission()

        return sysResource
    }

    @Transactional
    override fun deleteResourceById(id: Long) {
        baseMapper.physicalDeleteById(id)
        // 还要同时删掉 sys_resource_role 对应id的记录
        resourceRoleService.physicalDeleteByResourceId(id)
        ////
        permissionService.updateAllSysPermission()
        permissionService.updateAllSessionPermission()
    }

    override fun deleteResourcesByMenuId(menuId: Long) {
        val condition = SysResource().apply {
            this.menuId = menuId
        }
        baseMapper.physicalDelete(EntityWrapper(condition))
        ////
        permissionService.updateAllSysPermission()
        permissionService.updateAllSessionPermission()
    }
}
