package com.gxzc.zen.web.sys.controller

import com.gxzc.zen.api.sys.model.SysMenu
import com.gxzc.zen.api.sys.service.ISysMenuService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.dto.ResponseDto
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

/**
 * 菜单 控制器
 * @author NorthLan
 * @date 2018/5/1
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("menu")
class MenuController : BaseController() {
    companion object {
        private val logger = LoggerFactory.getLogger(MenuController::class.java)
    }

    @Autowired
    private lateinit var menuService: ISysMenuService

    @ApiOperation("获取系统菜单列表")
    @GetMapping("list")
    fun list(): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = menuService.getSysMenuList()
        })
    }

    @ApiOperation("获取系统菜单树")
    @GetMapping("tree")
    fun tree(): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = menuService.getSysMenuTree()
        })
    }

    @ApiOperation("新增菜单")
    @PostMapping
    fun create(@RequestBody entity: SysMenu): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = menuService.createSysMenu(entity)
        })
    }

    @ApiOperation("更新菜单项,不移动菜单")
    @PutMapping("{id}")
    fun udpate(@PathVariable id: Long, @RequestBody entity: SysMenu): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = menuService.updateMenu(entity)
        })
    }

    @ApiOperation("删除菜单以及子菜单")
    @DeleteMapping("{id}")
    fun delete(@PathVariable id: Long, @RequestBody entity: SysMenu): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = menuService.deleteMenu(entity)
        })
    }
}